@@ -1,20 +1,25 @@
 #!/usr/bin/env python
 # vim: ai ts=4 sts=4 et sw=4
+import logging
 
 from rapidsms.apps.base import AppBase
 from .utils import get_handlers
 
 
+logger = logging.getLogger(__name__)
+
+
 class App(AppBase):
 
-    def __init__(self, router):
-        """Spiders all apps, and registers all available handlers."""
-        super(App, self).__init__(router)
-
+    def __init__(self, *args, **kwargs):
+        """
+        Spiders all apps, and registers all available handlers.
+        """
+        super(App, self).__init__(*args, **kwargs)
         self.handlers = get_handlers()
         if len(self.handlers):
             class_names = [cls.__name__ for cls in self.handlers]
-            self.info("Registered: %s" % (", ".join(class_names)))
+            logger.info("Registered: %s" % (", ".join(class_names)))
 
     def handle(self, msg):
         """
@@ -26,5 +31,5 @@ class App(AppBase):
         """
         for handler in self.handlers:
             if handler.dispatch(self.router, msg):
-                self.info("Incoming message handled by %s" % handler.__name__)
+                logger.info("Incoming message handled by %s" % handler.__name__)
                 return True
