@@ -5,7 +5,7 @@ from django.utils.safestring import mark_safe
 
 import django_tables2 as tables
 
-from .models import HttpTesterMessage
+from rapidsms.backends.database.models import INCOMING, BackendMessage
 
 
 class MessageTable(tables.Table):
@@ -14,14 +14,14 @@ class MessageTable(tables.Table):
         # Render the phone number with a double arrow pointing to it
         # or away from it, depending on whether the message was going
         # out or coming in.
-        if record.direction == HttpTesterMessage.INCOMING:
+        if record.direction == INCOMING:
             return mark_safe(record.identity + "&raquo;")
         else:
             return mark_safe(record.identity + "&laquo;")
 
     class Meta:
-        model = HttpTesterMessage
+        model = BackendMessage
         sequence = ('date', 'identity', 'text')
-        exclude = ('id', 'direction')
+        exclude = ('id', 'direction', 'name', 'message_id', 'external_id')
         order_by = ('-date', )
         attrs = {'id': 'log'}
